# mlrose: Machine Learning, Randomized Optimization and SEarch - README
This repository contains the source code for the mlrose Python package. This package implements a range of Machine Learning, Randomized Optimization and SEarch algorithms, to allow users to explore the properties of these algorithms under various conditions.

## Installation
mlrose was written in Python 3 and requires NumPy, SciPy and Scikit-Learn (sklearn).

The latest released version is available at the Python package index < insert link to PyPi page> and can be installed using `pip`:

```
pip install mlrose
```

## Project Background


## Main Features

## Documentation
The official mlrose documentation can be found here: <Insert link>

## Licensing, Authors, Acknowledgements
mlrose was written by Genevieve Hayes and is distributed under the [3-Clause BSD license](https://github.com/gkhayes/mlrose/blob/master/LICENSE). 

You can cite mlrose in research publications and reports as follows:
* Hayes, G. (2018). ***mlrose: Machine Learning, Randomized Optimization and SEarch package for Python***. https://github.com/gkhayes/mlrose. Accessed: *day month year*.

BibTeX entry:
```
@misc{Hayes18,
 author = {Hayes, G},
 title 	= {{mlrose: Machine Learning, Randomized Optimization and SEarch package for Python}},
 year 	= 2018,
 howpublished = {\url{https://github.com/gkhayes/mlrose}},
 note 	= {Accessed: day month year}
}
```
